@@ -1,7 +1,7 @@
 /*
  * esekey.h --- ESE Key Daemon --- Keycode Daemon for Funny/Function Keys.
  *
- * $Id: esekey.h,v 1.2 2006-02-21 21:37:29 kb Exp $
+ * $Id: esekey.h 63 2010-07-04 20:23:51Z kb $
  *
  * (c) 2004,2006 Krzysztof Burghardt.
  *
@@ -19,17 +19,21 @@
 #include <syslog.h>
 #include <signal.h>
 #include <linux/input.h>
+#include "../version.h"
 #include "../config.h"
 
 #define INPUT_HANDLERS "/proc/bus/input/handlers"
 #define INPUT_DEVICES "/proc/bus/input/devices"
 #define EVENT_DEVICE "/dev/input/event"
 #define PID_FILE "/var/run/esekeyd.pid"
+#define KEY_SEPARATOR "+"
+#define KEYS_DELAY 300000
 
 struct esekey
 {
-  char *name;
-  char *command;
+    char *name;
+    int value;
+    char *command;
 };
 
 signed char check_handlers (void);
